@@ -18,7 +18,7 @@
 #
 """Render chart using gnuplot >= 4.2
 
-$Id: ReportRenderHtmlGnuPlot.py 54037 2009-11-25 20:16:17Z bdelbosc $
+$Id: ReportRenderHtmlGnuPlot.py 54214 2010-03-24 08:50:32Z bdelbosc $
 """
 
 import os
@@ -33,7 +33,7 @@ from datetime import datetime
 def gnuplot(script_path):
     """Execute a gnuplot script."""
     path = os.path.dirname(os.path.abspath(script_path))
-    if 'win' in sys.platform.lower():
+    if sys.platform.lower().startswith('win'):
         # commands module doesn't work on win and gnuplot is named
         # wgnuplot
         ret = os.system('cd "' + path + '" && wgnuplot "' +
@@ -132,6 +132,9 @@ class RenderHtmlGnuPlot(RenderHtmlBase):
                 has_error = True
             values.append(str(error))
             lines.append(' '.join(values))
+        if len(lines) == 1:
+            # No tests finished during the cycle
+            return
         f = open(data_path, 'w')
         f.write('\n'.join(lines) + '\n')
         f.close()
@@ -218,6 +221,9 @@ class RenderHtmlGnuPlot(RenderHtmlBase):
             values.append(str(page.percentiles.perc90))
             values.append(str(page.percentiles.perc95))
             lines.append(' '.join(values))
+        if len(lines) == 1:
+            # No pages finished during a cycle
+            return
         f = open(data_path, 'w')
         f.write('\n'.join(lines) + '\n')
         f.close()
@@ -297,6 +303,9 @@ class RenderHtmlGnuPlot(RenderHtmlBase):
             values.append(str(resp.percentiles.perc90))
             values.append(str(resp.percentiles.perc95))
             lines.append(' '.join(values))
+        if len(lines) == 1:
+            # No result during a cycle
+            return
         f = open(data_path, 'w')
         f.write('\n'.join(lines) + '\n')
         f.close()
@@ -382,6 +391,9 @@ class RenderHtmlGnuPlot(RenderHtmlBase):
             values.append(str(resp.percentiles.perc90))
             values.append(str(resp.percentiles.perc95))
             lines.append(' '.join(values))
+        if len(lines) == 1:
+            # No result during a cycle
+            return
         f = open(data_path, 'w')
         f.write('\n'.join(lines) + '\n')
         f.close()
